<?php
  /*
   Plugin Name: Proxy & VPN Blocker
   description: Proxy & VPN Blocker. This plugin will prevent Proxies and VPN's accessing your site's login page or making comments on pages & posts using the Proxycheck.io API
   Version: 1.5.1
   Author: RickstermUK
   Author URI: https://profiles.wordpress.org/rickstermuk
   License: GPLv2
   */

$version = '1.5.1';

if ( version_compare( get_option('proxy_vpn_blocker_version'), $version, '<' ) ) {
    update_option( 'proxy_vpn_blocker_version', $version );
}

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}
// Load plugin class files
require_once( 'includes/class-proxy-vpn-blocker.php' );
require_once( 'includes/plugin-options.php' );
require_once( 'includes/custom-form-handlers.php' );
// Load plugin libraries
require_once( 'includes/lib/class-proxy-vpn-blocker-admin-api.php' );

/**
 * Returns the main instance of proxy_vpn_blocker to prevent the need to use globals.
 *
 * @since  1.0
 * @return object proxy_vpn_blocker
 */
function proxy_vpn_blocker () {
    global $version;
	$instance = proxy_vpn_blocker::instance( __FILE__, $version );

	if ( is_null( $instance->settings ) ) {
		$instance->settings = proxy_vpn_blocker_Settings::instance( $instance );
	}

	return $instance;
}

proxy_vpn_blocker();



function disable_pvb_file_exists() {
    if ( is_file( ABSPATH . 'disablepvb.txt') ) {
        ?>
        <div class="error notice">
            <p><?php _e( 'Proxy & VPN Blocker is currently not protecting your site, disablepvb.txt exists in your WordPress root, please delete it!', 'proxy-vpn-blocker' ); ?></p>
        </div>
    <?php
    }
}

add_action( 'admin_notices', 'disable_pvb_file_exists' );

/**
* proxycheck integration
*
* @since 1.0
* @Updated 1.3.0
*/
function proxycheck_integrate(){
    if ( !is_file( ABSPATH . 'disablepvb.txt') ) {
        if (stripos($_SERVER['REQUEST_URI'], 'wp-cron.php') !== false) {
            //do nothing
        } else {
            if ( get_option('pvb_proxycheckio_CLOUDFLARE_select_box') == "on" && isset($_SERVER["HTTP_CF_CONNECTING_IP"])) {
                $Visitor_IP_Address = $_SERVER["HTTP_CF_CONNECTING_IP"];
            } else {
                $Visitor_IP_Address = $_SERVER["REMOTE_ADDR"];
            }
            include_once "proxycheckio-api-call.php";
            $proxycheckdenied = get_option('pvb_proxycheckio_denied_access_field');
   
            $blockedcountries = get_option('pvb_proxycheckio_blocked_countries_field');
            if ( isset($blockedcountries) && is_array($blockedcountries) ) { $Perform_Country_Check = 1; } else { $Perform_Country_Check = 0; }
   
            $proxycheck_answer = proxycheck_function($Visitor_IP_Address, $Perform_Country_Check);
            if ( $proxycheck_answer[0] == 1 ) {
                if (!empty(get_option('pvb_proxycheckio_custom_blocked_page'))) {
                    $redirect_to = array_values(get_option('pvb_proxycheckio_custom_blocked_page'));
                    wp_safe_redirect( $redirect_to[0] );
                    exit();
                } else {
                    define( "DONOTCACHEPAGE", true ); // Do not cache this page
                    wp_die( '<p>' . $proxycheckdenied . '</p>', $proxycheckdenied, array( 'back_link' => true ) );
                }
            }
   
            if ( $Perform_Country_Check == 1 && in_array($proxycheck_answer[1], $blockedcountries)) {
                if (!empty(get_option('pvb_proxycheckio_custom_blocked_page'))) {
                    $redirect_to = array_values(get_option('pvb_proxycheckio_custom_blocked_page'));
                    wp_safe_redirect( $redirect_to[0] );
                    exit();
                } else {
                    define( "DONOTCACHEPAGE", true ); // Do not cache this page
                    wp_die( '<p>' . __( 'Your country, ', 'proxy-vpn-blocker' ) .  $proxycheck_answer[1] . __( ', is blocked from viewing this page or website.', 'proxy-vpn-blocker' ) . '</p><p><strong>' .  __( 'Access      Denied', 'proxy-vpn-blocker' ) . '</strong></p>', $proxycheckdenied, array( 'back_link' => true ) );
                }
            }
            // No proxy has been detected so set a transient to cache this result and then return false.
            set_transient( "pvb_" . $Visitor_IP_Address, time()+1800 . "-" . 0, 60 * 30 );
        }
    }
}

/**
* For WooCommerce Account Login page we have to do something different to make it look nice.
*
* @since 1.0.2
* @Updated 1.3.0
*/
function proxycheck_woocommerce_integrate(){
    if ( !is_file( ABSPATH . 'disablepvb.txt') ) {
        if (stripos($_SERVER['REQUEST_URI'], 'wp-cron.php') !== false) {
            //do nothing
        } else {
            if ( get_option('pvb_proxycheckio_CLOUDFLARE_select_box') == "on" && isset($_SERVER["HTTP_CF_CONNECTING_IP"])) {
                $Visitor_IP_Address = $_SERVER["HTTP_CF_CONNECTING_IP"];
            } else {
                $Visitor_IP_Address = $_SERVER["REMOTE_ADDR"];
            }
            include_once "proxycheckio-api-call.php";
            $proxycheckdenied = get_option('pvb_proxycheckio_denied_access_field');
   
            $blockedcountries = get_option('pvb_proxycheckio_blocked_countries_field');
            if ( isset($blockedcountries) && is_array($blockedcountries) ) { $Perform_Country_Check = 1; } else { $Perform_Country_Check = 0; }
   
            $proxycheck_answer = proxycheck_function($Visitor_IP_Address, $Perform_Country_Check);
            if ( $proxycheck_answer[0] == 1 ) {
                $html = '<p>' . $proxycheckdenied . '</p>' . "\n";
                $html .= '<div class="woocomerceformremove" style="display: none;"' . "\n";
                echo $html;
            }
            if ( $Perform_Country_Check == 1 && in_array($proxycheck_answer[1], $blockedcountries)) {
                $html = '<p>' . __( 'Your country, ', 'proxy-vpn-blocker' ) .  $proxycheck_answer[1] . __( ', is blocked from viewing this page or website.', 'proxy-vpn-blocker' ) . '</p><p><strong>' .  __( 'Access Denied', 'proxy-vpn-blocker' ) . '</strong></p>' . "\n";
                $html .= '<div class="woocomerceformremove" style="display: none;"' . "\n";
                echo $html;
            }
            // No proxy has been detected so set a transient to cache this result and then return false.
            set_transient( "pvb_" . $Visitor_IP_Address, time()+1800 . "-" . 0, 60 * 30 );
        }
    }
}


/**
* proxycheck anti click-bomb inegration
*
* @since 1.4.0
*/
function pvb_anticlickbomb_scripts() {
        wp_register_script( 'anti-clickbomb-hidediv', plugin_dir_url(__FILE__) . 'assets/js/hide-div.js', array('jquery') );
        wp_enqueue_script( 'anti-clickbomb-hidediv' );
        wp_print_scripts('anti-clickbomb-hidediv');
}
function proxycheck_anti_clickbomb_integrate(){
    if ( !is_file( ABSPATH . 'disablepvb.txt') ) {
        if (stripos($_SERVER['REQUEST_URI'], 'wp-cron.php') !== false) {
            //do nothing
        } else {
            if ( get_option('pvb_proxycheckio_CLOUDFLARE_select_box') == "on" && isset($_SERVER["HTTP_CF_CONNECTING_IP"])) {
                $Visitor_IP_Address = $_SERVER["HTTP_CF_CONNECTING_IP"];
            } else {
                $Visitor_IP_Address = $_SERVER["REMOTE_ADDR"];
            }
            include_once "proxycheckio-api-call.php";
   
            $blockedcountries = get_option('pvb_proxycheckio_blocked_countries_field');
            if ( isset($blockedcountries) && is_array($blockedcountries) ) { $Perform_Country_Check = 1; } else { $Perform_Country_Check = 0; }
   
            $proxycheck_answer = proxycheck_function($Visitor_IP_Address, $Perform_Country_Check);
            if ( $proxycheck_answer[0] == 1 ) {
                define( "DONOTCACHEPAGE", true ); // Do not cache this page
            }
   
            if ( $Perform_Country_Check == 1 && in_array($proxycheck_answer[1], $blockedcountries)) {
                define( "DONOTCACHEPAGE", true ); // Do not cache this page
            }
            // No proxy has been detected so set a transient to cache this result and then return false.
            set_transient( "pvb_" . $Visitor_IP_Address, time()+1800 . "-" . 0, 60 * 30 );
        }
    }
}


/**
* proxycheck on select pages integration
*
* @since 1.0
* @Updated 1.3.0
*/
function proxycheck_select_pages_integrate(){
    if ( !is_file( ABSPATH . 'disablepvb.txt') ) {
        if (stripos($_SERVER['REQUEST_URI'], 'wp-cron.php') !== false) {
            //do nothing
        } else { 
            foreach (get_option('pvb_proxycheckio_blocked_select_pages_field') as $blockedpages) {
                if (strpos($_SERVER['REQUEST_URI'], $blockedpages) !== false) {
                    if ( get_option('pvb_proxycheckio_CLOUDFLARE_select_box') == "on" && isset($_SERVER["HTTP_CF_CONNECTING_IP"])) {
                    $Visitor_IP_Address = $_SERVER["HTTP_CF_CONNECTING_IP"];
                    } else {
                        $Visitor_IP_Address = $_SERVER["REMOTE_ADDR"];
                    }
                    include_once "proxycheckio-api-call.php";
                    $proxycheckdenied = get_option('pvb_proxycheckio_denied_access_field');
   
                    $blockedcountries = get_option('pvb_proxycheckio_blocked_countries_field');
                    if ( isset($blockedcountries) && is_array($blockedcountries) ) { $Perform_Country_Check = 1; } else { $Perform_Country_Check = 0; }
   
                    $proxycheck_answer = proxycheck_function($Visitor_IP_Address, $Perform_Country_Check);
                    if ( $proxycheck_answer[0] == 1 ) {
                        if (!empty(get_option('pvb_proxycheckio_custom_blocked_page'))) {
                            $redirect_to = array_values(get_option('pvb_proxycheckio_custom_blocked_page'));
                            wp_safe_redirect( $redirect_to[0] );
                            exit();
                        } else {
                            define( "DONOTCACHEPAGE", true ); // Do not cache this page
                            wp_die( '<p>' . $proxycheckdenied . '</p>', $proxycheckdenied, array( 'back_link' => true ) );
                        }
                    }
   
                    if ( $Perform_Country_Check == 1 && in_array($proxycheck_answer[1], $blockedcountries)) {
                        if (!empty(get_option('pvb_proxycheckio_custom_blocked_page'))) {
                            $redirect_to = array_values(get_option('pvb_proxycheckio_custom_blocked_page'));
                            wp_safe_redirect( $redirect_to[0] );
                            exit();
                        } else {
                            define( "DONOTCACHEPAGE", true ); // Do not cache this page
                            wp_die( '<p>' . __( 'Your country, ', 'proxy-vpn-blocker' ) .  $proxycheck_answer[1] . __( ', is blocked from viewing this page or website.', 'proxy-vpn-blocker' ) . '</p><p><strong>' .  __( 'Access      Denied', 'proxy-vpn-blocker' ) . '</strong></p>', $proxycheckdenied, array( 'back_link' => true ) );
                        }
                    }
                    // No proxy has been detected so set a transient to cache this result and then return false.
                    set_transient( "pvb_" . $Visitor_IP_Address, time()+1800 . "-" . 0, 60 * 30 );
                }
            }
        }
    }
}

/**
* proxycheck on select posts integration
*
* @since 1.5.0
*/
function proxycheck_select_posts_integrate(){
    if ( !is_file( ABSPATH . 'disablepvb.txt') ) {
        if (stripos($_SERVER['REQUEST_URI'], 'wp-cron.php') !== false) {
            //do nothing
        } else { 
            foreach (get_option('pvb_proxycheckio_blocked_select_posts_field') as $blockedposts) {
                if (strpos($_SERVER['REQUEST_URI'], $blockedposts) !== false) {
                    if ( get_option('pvb_proxycheckio_CLOUDFLARE_select_box') == "on" && isset($_SERVER["HTTP_CF_CONNECTING_IP"])) {
                    $Visitor_IP_Address = $_SERVER["HTTP_CF_CONNECTING_IP"];
                    } else {
                        $Visitor_IP_Address = $_SERVER["REMOTE_ADDR"];
                    }
                    include_once "proxycheckio-api-call.php";
                    $proxycheckdenied = get_option('pvb_proxycheckio_denied_access_field');
   
                    $blockedcountries = get_option('pvb_proxycheckio_blocked_countries_field');
                    if ( isset($blockedcountries) && is_array($blockedcountries) ) { $Perform_Country_Check = 1; } else { $Perform_Country_Check = 0; }
   
                    $proxycheck_answer = proxycheck_function($Visitor_IP_Address, $Perform_Country_Check);
                    if ( $proxycheck_answer[0] == 1 ) {
                        if (!empty(get_option('pvb_proxycheckio_custom_blocked_page'))) {
                            $redirect_to = array_values(get_option('pvb_proxycheckio_custom_blocked_page'));
                            wp_safe_redirect( $redirect_to[0] );
                            exit();
                        } else {
                            define( "DONOTCACHEPAGE", true ); // Do not cache this page
                            wp_die( '<p>' . $proxycheckdenied . '</p>', $proxycheckdenied, array( 'back_link' => true ) );
                        }
                    }
   
                    if ( $Perform_Country_Check == 1 && in_array($proxycheck_answer[1], $blockedcountries)) {
                        if (!empty(get_option('pvb_proxycheckio_custom_blocked_page'))) {
                            $redirect_to = array_values(get_option('pvb_proxycheckio_custom_blocked_page'));
                            wp_safe_redirect( $redirect_to[0] );
                            exit();
                        } else {
                            define( "DONOTCACHEPAGE", true ); // Do not cache this page
                            wp_die( '<p>' . __( 'Your country, ', 'proxy-vpn-blocker' ) .  $proxycheck_answer[1] . __( ', is blocked from viewing this page or website.', 'proxy-vpn-blocker' ) . '</p><p><strong>' .  __( 'Access      Denied', 'proxy-vpn-blocker' ) . '</strong></p>', $proxycheckdenied, array( 'back_link' => true ) );
                        }
                    }
                    // No proxy has been detected so set a transient to cache this result and then return false.
                    set_transient( "pvb_" . $Visitor_IP_Address, time()+1800 . "-" . 0, 60 * 30 );
                }
            }
        }
    }
}

/**
* activation switch to enable or disable querying. @since 1.1.0
*/
if ( get_option('pvb_proxycheckio_master_activation') == "on") {
	/**
	* WordPress Auth protection and comments protection. @since 1.0
	*/
	add_filter( 'authenticate', 'proxycheck_integrate', 1);
	add_filter( 'login_head', 'proxycheck_integrate', 1);
	add_action( 'pre_comment_on_post', 'proxycheck_integrate', 1);
	/**
	* WooCommerce Support for aesthetics. @since 1.0.2
	*/
	add_filter( 'woocommerce_before_customer_login_form', 'proxycheck_woocommerce_integrate', 1);
	/**
	* Enable block on specified PAGES option
	*/
    if ( !empty(get_option('pvb_proxycheckio_blocked_select_pages_field'))) {
        add_action( 'plugins_loaded', 'proxycheck_select_pages_integrate', 1);
        if (get_option('pvb_proxycheckio_all_pages_activation') == 'on') {
            update_option('pvb_proxycheckio_all_pages_activation', '');
        }
    }
    
    /**
	* Enable block on specified POSTS option
	*/
    if ( !empty(get_option('pvb_proxycheckio_blocked_select_posts_field'))) {
        add_action( 'plugins_loaded', 'proxycheck_select_posts_integrate', 1);
        if (get_option('pvb_proxycheckio_all_pages_activation') == 'on') {
            update_option('pvb_proxycheckio_all_pages_activation', '');
        }
    }
    /**
	* Enable for all pages option
	*/
    if ( get_option('pvb_proxycheckio_all_pages_activation') == "on") {
        add_action( 'plugins_loaded', 'proxycheck_integrate', 1);
        if (get_option('proxycheck_anti_clickbomb_integrate') == 'on') {
            update_option('proxycheck_anticlickbomb_integrate', '');
        }
    }
    /**
	* Anti click-bombing feature  @since 1.4.0
	*/
    if ( get_option('pvb_proxycheckio_anti_clickbomb') == "on") {
        add_action( 'plugins_loaded', 'proxycheck_anti_clickbomb_integrate', 1);
        add_action('wp_enqueue_scripts', 'pvb_anticlickbomb_scripts', 1);
        if (get_option('pvb_proxycheckio_all_pages_activation') == 'on') {
            update_option('pvb_proxycheckio_all_pages_activation', '');
        }
    }
} else if ( get_option('pvb_proxycheckio_master_activation') == "") {
	//do nothing
}
?>